<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field</source>
        <translation>שדה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field name</source>
        <translation>שם השדה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Field description</source>
        <translation>תיאור שדה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Value</source>
        <translation>ערך</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Field value</source>
        <translation>ערך שדה</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>לצאת עם הסגירה</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>לזכור את המיקום</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>איתור שם מארח</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>איתור שם שירות</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>משולשי חשיפה</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>קווי ענפים</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>שמירת ההגדרות אוטומטית עם היציאה</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>בחירה: העתקת מזהי תהליכים ללוח הגזירים</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>נרמול NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>להשתמש ב־pmap לשמות במפה</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>כללי</translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message>
        <location filename="../command.cpp" line="208"/>
        <source>The command:

</source>
        <translation>הפקודה:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="212"/>
        <source>

failed with the error:

</source>
        <translation>

נכשלה עם השגיאה:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="215"/>
        <source>Too many processes</source>
        <translation>יותר מדי תהליכים</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="218"/>
        <source>Unknown error</source>
        <translation>שגיאה לא ידועה</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="228"/>
        <source>

could not be executed because it was not found,
or you did not have execute permission.</source>
        <translation>

לא ניתן להרצה כיוון שלא נמצאה,
או שאין לך הרשאות להריץ.</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="233"/>
        <source>

exited with status </source>
        <translation>

יצאה עם המצב </translation>
    </message>
    <message>
        <location filename="../command.cpp" line="237"/>
        <source>Command Failed</source>
        <translation>הפקודה נכשלה</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../commanddialog.cpp" line="47"/>
        <source>Edit Commands 0.1 alpha</source>
        <translation>עריכת פקודות 0.1 אלפא</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="63"/>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="79"/>
        <source>Popup</source>
        <translation>חלון מוקפץ</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="84"/>
        <source>Command Line:</source>
        <translation>שורת פקודה:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="95"/>
        <source>Substitutions:
%p	PID
%c	COMMAND
%C	CMDLINE
%u	USER
%%	%

</source>
        <translation>החלפות:
%p	מזהה תהליך
%c	פקודה
%C	שורת פקודה
%u	משתמש
%%	%

</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="109"/>
        <source>New...</source>
        <translation>חדש…</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="111"/>
        <location filename="../commanddialog.cpp" line="229"/>
        <source>Add...</source>
        <translation>הוספה…</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="113"/>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="115"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="758"/>
        <source>Linear</source>
        <translation>קווי</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="761"/>
        <source>Tree</source>
        <translation>עץ</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="770"/>
        <source>Thread</source>
        <translation>תהליכון</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="777"/>
        <source>All Processes</source>
        <translation>כל התהליכים</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="778"/>
        <source>Your Processes</source>
        <translation>התהליכים שלך</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="779"/>
        <source>Non-Root Processes</source>
        <translation>תהליכים שאינם של משתמש העל</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="780"/>
        <source>Running Processes</source>
        <translation>תהליכים פעילים</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="796"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>עצירה (Ctrl+Space)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>תהליך %1 ( %2 ) - פרטים</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>קבצים</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>שקעים</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>מפות זיכרון</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>סביבה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>כל השדות</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable</source>
        <translation>משתנה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable name</source>
        <translation>שם המשתנה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Value</source>
        <translation>ערך</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Variable value</source>
        <translation>ערך המשתנה</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation>משגיח 0.1 אלפא</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation>יומן אירועים</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>בחירת מצב</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation>תווית תיאור</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>הפעלה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>שם תהליך</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation>מעבד</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>כולל תהליך שכבר רץ</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>הפעלת פקודה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>הצגת הודעה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>עזרה (בינתיים אין, זה בגדר רעיון)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>‎%p : מזהה תהליך
‎%c : פקודה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>חדש</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation>אישור</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="42"/>
        <source>Qps Watchdog</source>
        <translation>משגיח Qps</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="95"/>
        <source>%1 exit with code %2</source>
        <translation>%1 יצא עם קוד %2</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="97"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="103"/>
        <source>%1 [running]</source>
        <translation>%1 [פעיל]</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="104"/>
        <source>terminate command</source>
        <translation>חיסול פקודה</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="113"/>
        <source>Error %1 : [%2] Maybe command not found</source>
        <translation>שגיאה %1 ‏: [%2] אולי הפקודה לא נמצאה</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>בחירת שדות מותאמים אישית </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>File descriptor</source>
        <translation>מצביע קובץ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Mode</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Open mode</source>
        <translation>מצב פתיחה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File name (if available)</source>
        <translation>שם קובץ (אם יש)</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>שינוי טווח עדכון</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>טווח עדכון חדש</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>אין עדכון</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>ערך שגוי</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../listmodel.cpp" line="66"/>
        <source>Event Category</source>
        <translation>קטגוריית אירוע</translation>
    </message>
    <message>
        <location filename="../listmodel.cpp" line="68"/>
        <source>Enable</source>
        <translation>הפעלה</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>טווח כתובות</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>כתובות ממופות (הקס)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>קילובתים ממופים (עשרוני)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation>הרש׳</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>דגלוני הרשאה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>היסט</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>היסט מהקובץ לתחילת המיפוי (הקס)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>התקן</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>מספרי התקנים עיקריים, משניים (עשרוני)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation>תא מפרק</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>מספר Inode (יורד)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>קובץ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>שם קובץ (אם יש)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>הרשאה</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>ססמת משתמש על</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%מעבד לפי חלוקה של</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>סך ניצולת מעבד: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>מעבד יחיד: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>בררת מחדל</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>למפתח</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2850"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2850"/>
        <source>Process ID</source>
        <translation>מזהה תהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2852"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2852"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>מזהה קבוצת משימות (הורה התהליכים)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2854"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2854"/>
        <source>Parent process ID</source>
        <translation>מזהה תהליך הורה</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2856"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2856"/>
        <source>Process group ID</source>
        <translation>מזהה קבוצת תהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2858"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2858"/>
        <source>Session ID</source>
        <translation>מזהה הפעלה</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2860"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2860"/>
        <source>Terminal</source>
        <translation>מסוף</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2862"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2862"/>
        <source>Process group ID of tty owner</source>
        <translation>מזהה קבוצת תהליכים של בעלי מסוף (tty)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2864"/>
        <source>USER</source>
        <translation>USER</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2864"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>בעלות (‎*=suid משתמש על,‏ ‎+=suid משתמש)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2866"/>
        <source>GROUP</source>
        <translation>GROUP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2866"/>
        <source>Group name (*=sgid other)</source>
        <translation>שם קבוצה ‎(‎*=sgid אחר)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2868"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2868"/>
        <source>Real user ID</source>
        <translation>מזהה משתמש אמתי</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2870"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2870"/>
        <source>Effective user ID</source>
        <translation>מזהה משתמש בפועל</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2872"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2872"/>
        <source>Saved user ID (Posix)</source>
        <translation>מזהה משתמש שמור (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2874"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2874"/>
        <source>File system user ID</source>
        <translation>מזהה משתמש במערכת הקבצים</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2876"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2876"/>
        <source>Real group ID</source>
        <translation>מזהה קבוצה אמתי</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2878"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2878"/>
        <source>Effective group ID</source>
        <translation>מזהה משתמש בפועל</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2880"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2880"/>
        <source>Saved group ID (Posix)</source>
        <translation>מזהה משתמש שמור (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2882"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2882"/>
        <source>File system group ID</source>
        <translation>מזהה קבוצה במערכת הקבצים</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2884"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2884"/>
        <source>Dynamic priority</source>
        <translation>עדיפות דינמית</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2886"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2886"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>העדפת תזמון (יותר -&gt; פחות זמן מעבד)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2888"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2888"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>מספר המשימות (בתהליכי משנה) בקבוצת משימות</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2890"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2890"/>
        <source>Scheduling policy</source>
        <translation>מדיניות תזמון</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2892"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2892"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>עדיפות זמן אמת (0‏-99, יותר גדול זה יותר טוב)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2894"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2894"/>
        <source>Time slice in milliseconds</source>
        <translation>פיסת זמן במילישניות</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2896"/>
        <source>%SAVG</source>
        <translation>‎%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2896"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>זמן שינה ממוצע באחוזים (‎-1 -&gt; לא זמין)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2898"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2898"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>מסכת קרבה למעבד (0 -&gt; אין תמיכה ב־API)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2900"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2900"/>
        <source>Number of major faults (disk access)</source>
        <translation>מספר הכשלונות העיקריים (גישה לכונן)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2902"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2902"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>מספר הכשלונות המשניים (אין גישה לכונן)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2905"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2905"/>
        <source>Virtual image size of process</source>
        <translation>גודל התמונה הווירטואלית של תהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2907"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2907"/>
        <source>Resident set size</source>
        <translation>גודל ערכת התיישבות</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2909"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2909"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>שימוש בזיכרון (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2911"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2911"/>
        <source>Text(code) resident set size</source>
        <translation>גודל ערכת התיישבות טקסט (קוד)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2913"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2913"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation>גודל ערכת התיישבות נתונים (malloc + משתנים גלובליים)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2915"/>
        <source>STACK</source>
        <translation>STACK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2915"/>
        <source>Stack size</source>
        <translation>גודל מחסנית</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2917"/>
        <source>SHARE</source>
        <translation>SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2917"/>
        <source>Shared memory with other libs</source>
        <translation>זיכרון משותף עם ספריות אחרות</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2919"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2919"/>
        <source>Kbytes on swap device</source>
        <translation>קילובתים על התקן זיכרון ההחלפה</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2921"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2921"/>
        <source>io read (file)</source>
        <translation>קריאת קלט/פלט (קובץ)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2923"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2923"/>
        <source>io write (file)</source>
        <translation>כתיבת קלט/פלט (קובץ)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2925"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2925"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>מספר הדפים המלוכלכים (שלא נכתבו)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2927"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2927"/>
        <source>State of the process </source>
        <translation>מצב התהליך </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2929"/>
        <source>FLAGS</source>
        <translation>FLAGS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2929"/>
        <source>Process flags (hex)</source>
        <translation>דגלוני התהליך (הקסדצימלי)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2931"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2931"/>
        <source>Kernel function where process is sleeping</source>
        <translation>פונקציית ליבה שבה התהליך ישן</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2933"/>
        <source>%WCPU</source>
        <translation>‎%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2933"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>אחוז שקול ממעבד (30 שנ׳ בממוצא)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2935"/>
        <source>%CPU</source>
        <translation>‎%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2935"/>
        <source>Percentage of CPU used since last update</source>
        <translation>אחוז מהמעבד מאז העדכון האחרון</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2937"/>
        <source>%MEM</source>
        <translation>‎%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2937"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>אחוז הזיכרון בשימוש (RSS/סך כל הזיכרון)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2939"/>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2939"/>
        <source>Time process started</source>
        <translation>מועד התחלת התהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2941"/>
        <source>TIME</source>
        <translation>TIME</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2941"/>
        <source>Total CPU time used since start</source>
        <translation>זמן המעבד הכולל מאז ההתחלה</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2943"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2943"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>המעבד עליו פועל התהליך (מערכת SMP)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2945"/>
        <source>the process name</source>
        <translation>שם התהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2945"/>
        <source>Process Name</source>
        <translation>שם התהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2949"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2949"/>
        <source>Current working directory</source>
        <translation>תיקיית העבודה הנוכחית</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2950"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2950"/>
        <source>Root directory of process</source>
        <translation>תיקיית הבסיס של התהליך</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2953"/>
        <source>COMMAND_LINE</source>
        <translation>COMMAND_LINE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2953"/>
        <source>Command line that started the process</source>
        <translation>שורת הפקודה שהפעילה את התהליך</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1845"/>
        <source>Show</source>
        <translation>הצגה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1848"/>
        <source>Hide</source>
        <translation>הסתרה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1852"/>
        <source>Quit</source>
        <translation>יציאה</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="198"/>
        <source>header_popup</source>
        <translation>כותרת_חלונית</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="199"/>
        <source>Remove Field</source>
        <translation>הסרת שדה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="200"/>
        <source>Add Field</source>
        <translation>הוספת שדה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="207"/>
        <source>View</source>
        <translation>הצגה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="208"/>
        <source>Process</source>
        <translation>תהליך</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="209"/>
        <source>Log</source>
        <translation>יומן</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Fields</source>
        <translation>שדות</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="215"/>
        <source>Custom Fields</source>
        <translation>שדות בהתאמה אישית</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="217"/>
        <source>Basic Fields </source>
        <translation>שדות בסיסיים </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="219"/>
        <source>Jobs Fields </source>
        <translation>שדות משימות </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="221"/>
        <source>Memory Fields </source>
        <translation>שדות זיכרון </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Scheduling Fields </source>
        <translation>שדות תזמון </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="241"/>
        <source>Select Custom Fields...</source>
        <translation>בחירת שדות בהתאמה אישית…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="203"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="255"/>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="256"/>
        <source>Update Period...</source>
        <translation>טווח עדכון…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="265"/>
        <source>Show Status bar</source>
        <translation>הצגת סרגל מצב</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="274"/>
        <source>Preferences...</source>
        <translation>העדפות…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="280"/>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="282"/>
        <location filename="../qps.cpp" line="1893"/>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="370"/>
        <source>Detail</source>
        <translation>פרט</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>test</source>
        <translation>בדיקה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="412"/>
        <source>Copied to Clipboard</source>
        <translation>הועתק ללוח גזירים</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="464"/>
        <source>context popup</source>
        <translation>חלונית הקשר</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="465"/>
        <source>Renice...</source>
        <translation>Nice מחדש…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="466"/>
        <source>Scheduling...</source>
        <translation>תזמון…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="468"/>
        <source>Terminate</source>
        <translation>חיסול</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="470"/>
        <source>Hangup</source>
        <translation>ניתוק</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="471"/>
        <source>Kill</source>
        <translation>הריגה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="472"/>
        <source>Stop</source>
        <translation>עצירה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="474"/>
        <source>Continue</source>
        <translation>המשך</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="477"/>
        <source>Other Signals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="478"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (פסיקה)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="480"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (המשך)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="482"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (עצירה)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="484"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (יציאה)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="486"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (הנחייה בלתי חוקית)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="488"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (ביטול)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="490"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (חריגת נקודה עשרונית)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="492"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (הפרת סגמנטציה)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="494"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (תעלה סתומה)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="496"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (אות תזמון)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="498"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (הגדרת משתמש 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="500"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (הגדרת משתמש 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="502"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (מות צאצא)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="504"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (עצירה מ־tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="506"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (קלט tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="508"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (פלט tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="515"/>
        <source>View Details</source>
        <translation>הצגת פרטים</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="781"/>
        <source>Show File Path</source>
        <translation>הצגת נתיב הקובץ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="787"/>
        <source>Show Graph</source>
        <translation>הצגת תרשים</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="793"/>
        <source>Show Control Bar</source>
        <translation>הצגת סרגל הבקרה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="804"/>
        <source>Include Child Times</source>
        <translation>לכלול את זמני הצאצאים</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="998"/>
        <source>WatchDog</source>
        <translation>משגיח</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1000"/>
        <source>Edit Commands...</source>
        <translation>עריכת פקודות…</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1016"/>
        <source>Quit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1335"/>
        <location filename="../qps.cpp" line="1366"/>
        <location filename="../qps.cpp" line="1373"/>
        <location filename="../qps.cpp" line="1394"/>
        <location filename="../qps.cpp" line="1428"/>
        <location filename="../qps.cpp" line="1523"/>
        <source>Permission denied</source>
        <translation>ההרשאה נדחתה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1336"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>אין לך אפשרות לשנות nice של התהליכים הנבחרים. רק הבעלים ומשתמש העל מורשים לעשות זאת.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1367"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>אין לך אפשרות לשנות nice לתהליך %1 (%2). רק הבעלים של התהליך ומשתמש העל מורשים לעשות זאת.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1374"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>רק משתמש העל יכול להוריד את ערך ה־nice של תהליך.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1395"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>רק משתמש העל יכול לשנות את מדיניות התזמון ואת העדיפות הסטטית.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1429"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>אין לך הרשאות לשנות את התזמון ו/או העדיפות של התהליך %1 (%2). רק משתמש העל יכול לעשות זאת.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1490"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>לחסל את התהליך או התהליכים הנוכחיים?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1492"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>לנתק את התהליך או התהליכים הנבחרים?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1494"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>להשמיד את התהליך או התהליכים הנוכחיים?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1503"/>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1524"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>אין לך הרשאות לשלוח אות לתהליך %1 (%2). רק משתמש העל והבעלים של התהליך יכולים לשלוח אליו אותות.</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1909"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1911"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - מנהל תהליכים חזותי &lt;/h2&gt; %2 משתמש בספריית Qt %3&lt;br&gt;&lt;br&gt;&lt;b&gt;מקור: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;מערכת התקלות: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1931"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation>&lt;b&gt;ה־Qps המקורי נוצר על ידי&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;תורמים&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1969"/>
        <source>&lt;H1&gt;QPS Help&lt;/H1&gt;Updated: May 24 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</source>
        <translation>&lt;H1&gt;העזרה שלQPS&lt;/H1&gt;מועד העדכון: 24 במאי 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;יציאה      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;עדכון      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; חיסול תהליך &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; הריגת תהליך &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>החלפת תזמון</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>מדיניות תזמון</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (חלוקת זמן)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (זמן אמת)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (זמן אמת)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>עדיפות (1‏-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>קלט שגוי</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>העדיפות חייבת להיות בטווח שבין 1 ל־99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="712"/>
        <source>PID, COMMAND, USER...</source>
        <translation>PID, COMMAND, USER…</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="713"/>
        <source>Filter</source>
        <translation>מסנן</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation>Nice מחדש על תהליך</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>ערך Nice חדש:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation>Fd</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>מצביע קובץ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation>פרוטו</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>פרוטוקול (TCP או UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation>תור נכנס</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>בתים בתור הקבלה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation>תור יוצא</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>בתים בתור השליחה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>כת׳ מקומית</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>כתובת IP מקומית</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation>פתחה</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>פתחה מקומית</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>כת׳ מרוחקת</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>כתובת IP מרוחקת</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>פתחה מרוחקת</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>מצב</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>מצב החיבור</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="748"/>
        <source>Process count: %1</source>
        <translation>כמות תהליכים: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="347"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> זו תכונת אלפא שאינה יציבה
 יתכן שיופיע לך SEGFAULT…</translation>
    </message>
</context>
<context>
    <name>TFrame</name>
    <message>
        <location filename="../misc.cpp" line="426"/>
        <source>this is Tframe widget</source>
        <translation>זה וידג׳ט מסוג Tframe</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="610"/>
        <source>title</source>
        <translation>כותרת</translation>
    </message>
</context>
<context>
    <name>WatchdogDialog</name>
    <message>
        <location filename="../watchdogdialog.cpp" line="191"/>
        <source>if process start</source>
        <translation>אם תהליך מתחיל</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="192"/>
        <source>if process finish</source>
        <translation>אם תהליך מסתיים</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="215"/>
        <source>select condition</source>
        <translation>בחירת תנאי</translation>
    </message>
</context>
</TS>
